package AccountManager::App::Step2;

use Mojo::Base qw(AccountManager::App::Controller);

use English qw(-no_match_vars);
use Syntax::Keyword::Try;

use AccountManager::Entity;

sub run {
    my $self = shift;

    my $config = $self->app()->config();
    my $log    = $self->app()->log();

    $self->init_db();
    $self->init_l10n();

    if ($config->{app}->{login_url}) {
        return if !$self->check_authentication();
    }

    my $entityid = $self->param('entityid');
    my $db       = $self->stash('db');

    my $sp = AccountManager::Entity->new(
        db       => $db,
        entityid => $entityid
    );
    return $self->abort(
        log_message  => sprintf("No such SP '%s' in database", $entityid),
        user_message => "no_such_entity"
    ) if !$sp->load(speculative => 1);

    # override metadata contacts if needed
    my $contacts =
        $config->{$entityid}->{contacts} ||
        $config->{service}->{contacts};
    if ($contacts) {
        if ($contacts =~ /^\+(.+)/) {
            # complement original contacts
            $sp->contacts($sp->contacts(), split(/, */, $1));
        } else {
            # replace original contacts
            $sp->contacts(split(/, */, $contacts));
        }
    }

    $self->stash(sp => $sp);
    $self->stash(entityid => $entityid);

    $self->render(
        status   => 200,
        template => 'select_email',
        format   => 'html'
    );
}

1;
